/* http://www.positioniseverything.net/easyclearing.html */
.clearfix:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}
.clearfix {display: inline-block;}
/* Hides from IE-mac \*/
.clearfix {display: block;}
* html .clearfix {height: 1%;}
/* end hide from IE-mac */

html * { padding:0; margin:0; }
body * * { padding:0; }
body {
    font: small "Lucida Grande", "Lucida Sans", verdana, sans-serif;
    background: #E5E5E5;
}
h1 a { color: inherit; text-decoration: none; }
h2 span { font-size:80%; color:#666; font-weight:normal; }

h1, h2, h3, h4, h5, h6 {
    font-weight: normal;
}

h1, h2, h3, h4, h5, h6, p, ul,
table, form, pre, ol { margin-bottom: 20px; }
ul { margin: 0 0 20px 20px; }

a { color: #333; }
a:visited { color: inherit; }

pre {
    display: block;
    white-space: pre-wrap;       /* CSS-3                  */
    white-space: -moz-pre-wrap;  /* Mozilla, since 1999    */
    white-space: -pre-wrap;      /* Opera 4-6              */
    white-space: -o-pre-wrap;    /* Opera 7                */
    word-wrap: break-word;       /* Internet Explorer 5.5+ */
}

#header {
    position: relative;
    background: #e0ebff; border-bottom:1px solid #ddd;
    background: #555; /* for non-css3 browsers */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#555555', endColorstr='#222222'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#555555), to(#222222)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #555,  #222); /* for firefox 3.6+ */
    border-bottom: 1px solid #000;
}

#header h1, #header h2 { margin-bottom: 0; }

#header .container {
    position: relative;
    padding: 1em 2em;
    max-width: 1550px;
}
#header .sparkline {
    padding: 5px;
    position: absolute;
    right: 45px;
    top: 20px;
}

#header h1 {
    font-family: 'Yanone Kaffeesatz', arial, serif;
    display: inline-block;
    font-size: 24px;
    line-height: 36px;
    color: #e5e5e5;
    text-shadow: 1px 1px 1px #333;
    font-weight: normal;
}
#header h1 img { float: left; height: 36px; margin-right: 10px; }
#header h2 {
    font-family: 'Yanone Kaffeesatz', arial, serif;
    display: inline-block;
    font-size: 20px;
    line-height: 36px;
    margin-top: 0;
    font-weight: normal;
    color: #888;
    margin-bottom: 0;
    margin-left: 15px;
    color: #ccc;
}
#header h2 span {
    display: inline-block;
    line-height: 36px;
    color: #fff;
    margin-left: 10px;
}
#header h2 span a {
    text-decoration: none;
}

#account {
    position: absolute;
    right: 35px;
    bottom: 6px;
    padding-left: 20px;
    background: #e5e5e5;
}
#search {
    position: absolute;
    right: 35px;
    top: 1.4em;
    width: 300px;
}
#search input {
    width: 244px;
    padding: 6px 50px 6px 6px;
    background: #000;
    border:1px solid #666;
    color: #fff;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
}
#search button {
    cursor: pointer;
    position: absolute;
    right: -2px;
    top: 0;
    padding: 6px;
    height: 100%;
    line-height: 100%;
    font-weight: bold;
    text-transform: uppercase;
    background: #e0ebff;
    background: #555; /* for non-css3 browsers */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#555555', endColorstr='#222222'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#555555), to(#222222)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #555,  #222); /* for firefox 3.6+ */
    border: 1px solid #666;
    color: #fff;
    -moz-border-radius: 0 3px 3px 0;
    -webkit-border-radius: 0 3px 3px 0;
    border-radius: 0 3px 3px 0;
}
#search button:hover {
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#777777', endColorstr='#555555'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#777777), to(#555555)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #777777,  #555555); /* for firefox 3.6+ */
}


.nav {
    list-style: none;
    margin-left: 0;
}
.nav a { color: inherit; }
.nav li { display: inline; }
.nav li a { display: inline-block; }


#footer {
    clear: both;
    border-top:1px solid #ddd;
    background-color: #e5e5e5;
}
#footer .container {
    color: #666;
    padding: 2em;
    max-width: 1550px;
    position: relative;
}
#header table { border:none; background:transparent; }
#body, #sidebar { position: relative; }
#body {
    background: #fff;
    max-width: 100%;
    overflow: hidden;
    margin: 2em 0 2em 2em;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    -moz-box-shadow: 0 1px 4px #c5c5c5;
    -webkit-box-shadow: 0 1px 4px #c5c5c5;
    box-shadow: 0 1px 4px #c5c5c5;
    padding: 10px 10px 0;
    min-height: 800px;
}

#content {
    border-top: 1px solid #fff;
    overflow: hidden;
    background: #EEEEEE;
    min-width: 900px;
}

.container {
    max-width: 1600px;
    margin: 0 auto;
}

/* sidebar */

#sidebar {
    float: right;
    width: 300px;
    margin: 0em 2em 2em 1.5em;
    background: inherit;
    overflow: hidden;
}

.sidebar-module {
    background: #fff;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    -moz-box-shadow: 0 1px 4px #c5c5c5;
    -webkit-box-shadow: 0 1px 4px #c5c5c5;
    box-shadow: 0 1px 4px #c5c5c5;
    position: relative;
}
.sidebar-module-content {
    background: transparent;
}

.sidebar-module h2 {
    color: #fff;
    margin: 0;
    padding: 5px 10px;
    font-size: 1.1em;
    border-radius: 5px 5px 0 0;
    -moz-border-radius: 5px 5px 0 0;
    -webkit-border-radius: 5px 5px 0 0;
    -moz-box-shadow: inset 0 0 1px #22579b, 0 1px 0 #fff;
    -webkit-box-shadow: inset 0 0 1px #22579b, 0 1px 0 #fff;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */
}

.filter-list { margin-left: 0; text-transform: lowercase; }
.filter-select {
    padding: 10px;
}
.filter-select select {
    width: 100%;
}
.filter-list li a {
    display: block;
    padding: 5px 10px;
    text-decoration: none;
    border-bottom: 1px solid rgba(0,0,0, .05);
    -moz-box-shadow: 0 1px 0 rgba(255,255,255, .3);
     -webkit-box-shadow: 0 1px 0 rgba(255,255,255, .3);
    color: #666;
}

.filter-list li a:hover  {
    background: rgba(131,136,142, .20);
    -moz-box-shadow: inset 0 1px 0 rgba(0,0,0, .1);
    -webkit-box-shadow: inset 0 1px 0 rgba(0,0,0, .1);
}
.filter-list li.active a {
    color: #3079d0;
    font-weight: bold;
}
.filter-list li:last-child a {
    border-radius: 0 0 5px 5px;
    -moz-border-radius: 0 0 5px 5px;
    -webkit-border-radius: 0 0 5px 5px;
}

.filter-text {
    position: relative;
}

.filter-text p {
    margin-bottom: 0;
}

.filter-text input[type=text] {
    margin: 2px;
    border: 0;
    background: transparent;
    padding: 8px;
    color: #666;
    width: 277px;
    font-size: 1em;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    border: 1px solid #ddd;
}

.filter-text .submit {
    position: absolute;
    right: 14px;
    top: 12px;
    opacity: .6;
}

.filter-text .search-submit {
    display: block;
    width: 12px;
    height: 12px;
    background: #fff url(../images/search.png);
    text-indent: -9999em;
    border: none;
    cursor: pointer;
}

#chart { margin-bottom: 20px; }

/* tracebacks */
.frame table.vars { margin:5px 0 2px 40px; }
table.vars tbody td:first-child { padding-right: 20px; }
table.vars td { font-family:monospace; }
table.vars td.code { overflow: hidden; }
table.vars td.code pre { margin-bottom: 0; }
div.pastebin textarea { padding: 10px; background: #f9f9f9; border-color: #ddd; }
table.vars { border-collapse: collapse; background:white; margin-bottom: 10px; }
table tbody td, table tbody th { vertical-align:top; padding:2px 3px; }
table.meta th { text-align: right; white-space: nowrap; }
table.vars thead th { padding:3px 6px 3px 3px; background:#eee; text-align:left; font-weight:bold; border:1px solid #ddd; border-width: 1px 0; font-size:11px; }

table.source th { color:#666; }
table.source td { font-family:monospace; white-space:pre; border-bottom:1px solid #eee; }
ul.traceback { list-style-type:none; }
ul.traceback li.frame { margin-bottom:1em; overflow: hidden; position: relative; }
div.context { margin: 10px 0; }
div.context ol { padding-left:30px; margin:0 10px; list-style-position: inside; }
div.context ol li { font-family:monospace; white-space:pre; color:#666; cursor:pointer; }
div.context ol.context-line li { color:black; background-color:#ccc; }
div.context ol.context-line li span { float: right; }
div.commands { margin-left: 40px; }
div.commands a { color:black; text-decoration:none; }
#template, #template-not-exist { background:#f6f6f6; margin-top: 1em; overflow: hidden; }
#template-not-exist ul { margin: 0 0 0 20px; }
#unicode-hint { background:#eee; }
#traceback { }
#summary, #traceback, #unicode-hint, #template, #requestinfo, #versioninfo { margin-bottom: 20px; }
#summary table, #summary pre { margin-bottom: 0; }
#summary pre {
    line-height: 16px;
}
#summary h3 { font-weight: normal; font-size: 1.5em; }
#explanation { background:#eee; }
#summary table { border:none; background:inherit; }

/** variables **/
#requestinfo { overflow: hidden; }
#requestinfo > table { border: 0; width: 100%; margin-bottom: 0; }
#requestinfo th.key, #requestinfo td.values { padding: 0 0 20px; position: relative; }
#requestinfo th.key { vertical-align: top; font-size: 1.1em; text-align: left; padding-right: 30px; }
#requestinfo td.values td { }
#requestinfo td.values th { text-align: left; }

#versioninfo th { text-align: left; font-family: monospace; padding-right: 20px; }
#versioninfo tr:nth-child(odd) {
    background: #eee;
}

#reporter_body #traceback li { list-style-type: inherit; }
#reporter_body #traceback { padding: 8px; margin-top: 10px; }
#reporter_body td, #reporter_body th { border-bottom: 0; font:small sans-serif; line-height: auto; }
.error { background: #ffc; padding: 5px; }
.specific { color:#cc3300; font-weight:bold; }
h2 span.commands { font-size:.7em;}
span.commands a:link {color:#5E5694;}
pre.exception_value { font-family: sans-serif; font-weight: normal; color: #333; font-size: 1.5em; }

/* message details */
.server-list, .url-list, .logger-list, .level-list { list-style: none; margin-left: 0; }
.server-list li, .url-list li { padding-bottom: 10px; }
.url-list li a { line-height: 18px; }

dl.flat {
    margin-bottom: 1em;
}
dl.flat dt {
    float: left;
    clear: left;
    width: 90px;
    padding-bottom: 5px;
}
dl.flat dd {
    padding-bottom: 5px;
}
/* messages generic */
.count { background: #000; -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px; padding: 0 5px; margin-right: 3px; line-height: 19px; color: #fff; display: inline-block; }
.count-digits-4 { font-size: 0.8em; }
.count-digits-5 { font-size: 0.7em; }

/* message list */
.messages { list-style: none; margin-left: 0; }
.messages li { list-style: none; }
.messages .no-messages {
    font-weight: bold;
}
.messages .count {
    width: 28px;
    vertical-align: top;
    text-align: center;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    padding: 4px;
    line-height: 19px;
    color: #fff;
    display: inline-block;
    margin-right: 5px;
}
.messages h3 {
    vertical-align: middle;
    font-weight: bold;
    line-height: 24px;
    display: inline-block;
    margin: 0;
    max-width: 80%;
}
.messages h3 a { text-decoration: none; }
.messages .message {
    color: #666;
    margin-top: 8px;
    font-size: 0.9em;
    margin-bottom: 0;
    overflow: hidden;
    white-space: nowrap;
}

.messages .tag { display: inline-block; padding: 2px 5px; background: #eaeaea; margin-right: 5px;}
.messages .traceback { display: none; }
.messages li { clear: both; padding: 8px; position: relative; padding-right: 50px; overflow: hidden; }
.messages .row1 { background: #f9f9f9; }
.messages .hidden {
    position: absolute;
    right: 15px;
    top: 21px;
    visibility: hidden;;
}
.messages li:hover .hidden {
    visibility: visible;
}

.messages .row_link {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    position: absolute;
}

.messages .last_seen {
    color: #bbb;
    font-size: 0.9em;
    margin-left: 5px;
    white-space: nowrap;
    vertical-align: middle;
    display: inline-block;
}
.messages .status { margin-left: 5px; text-transform: uppercase; font-size: 0.9em; }
.messages .status-0 { display: none; }
.messages .status-1 { color: red; }
.messages li:hover, .messages .active {
    background: #eaeaea;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
}
.messages li:hover .tag { background: #fff; }
.messages li:hover h3 a {
    color: #0099dc;
}
.messages li:hover .last_seen, .messages .active .last_seen { color: #777; }

.button {
    cursor: pointer;
    display: inline-block;
    color: #888;
    padding: 5px 8px 5px 8px;
    font-size: 12px;
    line-height: 12px;
    border:1px solid #C5C5C5;
    text-decoration: none;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.button:hover {
    border:1px solid #3079d0;
    color: #fff;
    text-shadow: 0 -1px 0 #3079d0;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */

}
.priority-veryhigh .count {
    background: #e22e2e;
    -webkit-box-shadow: 0 1px 2px rgba(0,0,0,.2);
    -moz-box-shadow: 0 1px 2px rgba(0,0,0,.2);
    box-shadow: 0 1px 2px rgba(0,0,0,.2);
    background:-moz-linear-gradient(center top , #ED1C24, #AA1317) repeat scroll 0 0 transparent;
    background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#ED1C24), to(#AA1317));
}
.priority-high .count {
    background: #ff5400;
    background:-moz-linear-gradient(center top , #F16C7C, #BF404F) repeat scroll 0 0 transparent;
    background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#F16C7C), to(#BF404F));
}
.priority-medium .count {
    background: #ff7800;
    background:-moz-linear-gradient(center top , #FAA51A, #F47A20) repeat scroll 0 0 transparent;
    background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#FAA51A), to(#F47A20));
}
.priority-low .count,
.priority-verylow .count {
    background: #ffb400;
    background:-moz-linear-gradient(center top , #efd57c, #e0ae00) repeat scroll 0 0 transparent;
    background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#efd57c), to(#e0ae00));
}

.no-messages { font-size: 1.1em; padding: 10px 0; }

.paging-wrap {
    display: inline;
    float: left;
    width: 100%;
    margin-bottom: 10px;
}
.paging-wrap form { margin-bottom: 0; }
.paging-meta, .sort-by, .realtime {
    display: inline;
    float: right;
    margin: 0 0 0 10px;
    font-size: 14px;
    line-height: 17px;
    color: #aaa;
    font-weight: bold;
}
.paging-meta {
    padding: 6px 8px;
}
.paging-endless {
    display: inline; float: left;
    margin-left: 0;
}

.paging-endless li {
    float: left; display: inline;
    margin-right: 15px;
}

.paging-endless li span {
    display: inline-block;
    padding: 6px 8px 6px 8px;
    color: #aaa;
    font-size: 12px;
    line-height: 17px;
    border:1px solid #ddd;
    text-decoration: none;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    opacity: 0.75;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.paging-endless li a,
.sort-by, .realtime {
    display: inline-block;
    text-decoration: none;
    color: #888;
    padding: 6px 8px 6px 8px;
    font-size: 12px;
    line-height: 17px;
    border:1px solid #C5C5C5;
    text-decoration: none;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.paging-endless li a:hover,
.realtime:hover {
    cursor: pointer;
    border:1px solid #3079d0;
    color: #fff;
    text-shadow: 0 -1px 0 #3079d0;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
    background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
    background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */
}

.sort-by select {
    border: 0;
    margin-left: 4px;
    background: inherit;
}

.login-area {
    width: 300px;
    margin: 50px auto;
    background: #eee;
    border: 1px solid #ddd;
    padding: 10px;
}
.login-area p {
    margin-bottom: 10px;
}
.login-form table { width: 295px; }
.login-form td { padding: 2px 0; }
form table {
    border: 0;
    margin: 1em 0;
    background: inherit;
}
form table td { padding: 5px; }
form .submit { text-align: right; }
form .has-errors input,
form .has-errors textarea { border-color: red; }
form td .errors { color: red; margin-top: 5px; font-size: 0.9em; }

form td textarea {
    min-height: 250px;
}
form td textarea,
form td input {
    width: 100%;
    padding: 3px;
    border: 1px solid #ccc;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
}
form td textarea:focus,
form td input:focus {
    border-color: #333;
}

#group_nav {
    border-bottom: 1px solid #ddd;
}
#group_nav a {
    -moz-border-radius: 5px 5px 0 0;
    -webkit-border-radius: 5px 5px 0 0;
    border-radius: 5px 5px 0 0;
    padding: 6px 12px;
    text-decoration: none;
}
#group_nav a:hover {
    background: #eee;
}
#group_nav .active a {
    background: #ddd;
    font-weight: bold;
    color: #000;
}
h2 .morelink { text-decoration: none; }

#full-message {
    line-height: 1.5em;
}

/* breadcrumbs */

#breadcrumbs {
    font-size: 0.9em;
    height: 16px;
    line-height: 16px;
    margin: 0 0 20px;
}
#breadcrumbs li {
    list-style: none;
    display: inline;
    float: left;
}
#breadcrumbs a,
#breadcrumbs span {
    font-weight: normal;
    background: url('../images/breadcrumb.png') right center no-repeat;
    padding: 0 12px 0 0;
    margin: 0 8px 0 0;
}
#breadcrumbs li:last-child {
    background: none;
    font-weight: bold;
}
#breadcrumbs li:last-child a,
#breadcrumbs li:last-child span {
    background: none;
    text-decoration: none;
    font-weight: inherit;
    padding-right: 0;
    margin-right: 0;
}