{% extends "sentry/group/details.html" %}

{% load sentry_helpers %}

{% block inner %}
    <h2>URL List</h2>
    {% paginate group.unique_urls from request as url_list per_page 25 %}
    <div class="clearfix">
        {{ url_list.paging }}
    </div>
    <ul class="url-list">
        {% for link in url_list.objects %}
            <li><span class="count">{{ link.times_seen }}</span> <a href="{{ link.url }}">{{ link.url }}</a></li>
        {% endfor %}
    </ul>
    <div class="clearfix">
        {{ url_list.paging }}
    </div>
{% endblock %}