{% extends "sentry/layout.html" %}

{% load i18n %}
{% load sentry_helpers %}

{% block title %}{% trans "Login" %} | {{ block.super }}{% endblock %}

{% block heading %}{% trans "Login" %}{% endblock %}

{% block search %}{% endblock %}

{% block content %}
    <div id="body">
        <div class="login-area">
            <p>{% trans "You must log in to continue" %}</p>
        
            {% if form.errors %}
                <p class="error">{% trans "Your username and password didn't match. Please try again." %}</p>
            {% endif %}

            <form method="post" action="" class="login-form">
                <input type="hidden" name="next" value="{{ next }}" />
            
                {% csrf_token %}
                <table>
                    <colgroup>
                        <col width="100px"/>
                        <col/>
                    </colgroup>
                    <tr>
                        <td>{{ form.username.label_tag }}</td>
                        <td>{{ form.username }}</td>
                    </tr>
                    <tr>
                        <td>{{ form.password.label_tag }}</td>
                        <td>{{ form.password }}</td>
                    </tr>
                </table>
                <div class="submit">
                    <button type="submit" class="button">{% trans "Login" %}</button>
                </div>
            </form>
        </div>
    </div>
{% endblock %}
