{% extends "sentry/layout.html" %}

{% load i18n %}

{% block heading %}{% trans "Search" %}{% endblock %}

{% block main %}
    <p>{% trans "We were unable to find a message matching the ID you entered." %}</p>
{% endblock %}
