{% extends BASE_TEMPLATE %}

{% block inner %}
    <h2>Create Redmine Issue</h2>
    <form method="post" action="">
        <input type="hidden" name="next" value="{{ next }}" />
        {% csrf_token %}
        {% if global_errors %}
            <p class="error">{{ global_errors }}</p>
        {% endif %}
        <table>
            <colgroup>
                <col width="100px"/>
                <col/>
            </colgroup>
            <tr{% if form.subject.errors %} class="has-errors"{% endif %}>
                <td>{{ form.subject.label_tag }}</td>
                <td>
                    {{ form.subject }}
                    {% if form.subject.errors %}
                        <div class="errors">{{ form.subject.errors|join:", " }}</div>
                    {% endif %}
                </td>
            </tr>
            <tr{% if form.description.errors %} class="has-errors"{% endif %}>
                <td>{{ form.description.label_tag }}</td>
                <td>
                    {{ form.description }}
                    {% if form.description.errors %}
                        <div class="errors">{{ form.description.errors|join:", " }}</div>
                    {% endif %}
                </td>
            </tr>
        </table>
        <div class="submit">
            <button type="submit" class="button">Create Issue</button>
        </div>
    </form>
{% endblock %}