{% extends "sentry/group/details.html" %}

{% load sentry_helpers %}

{% block inner %}
    <h2>Server List</h2>
    {% paginate group.unique_servers from request as server_list per_page 25 %}
    <div class="clearfix">
        {{ server_list.paging }}
    </div>
    <ul class="server-list">
        {% for server in server_list.objects %}
            <li><span class="count">{{ server.times_seen }}</span> <a href="{% url sentry %}?server_name={{ server.server_name }}">{{ server.server_name }}</a></li>
        {% endfor %}
    </ul>
    <div class="clearfix">
        {{ server_list.paging }}
    </div>
{% endblock %}